
# uncomment to enable bootstrap mode
#global bootstrap 1

%if ! 0%{?bootstrap}
%global docs 1
%global tests 1
%endif

Name:    libalkimia
Summary: Financial library
Version: 7.0.2
Release: 2%{?dist}

License: LGPLv2+
URL:     https://kmymoney.org/
Source0: http://download.kde.org/stable/alkimia/%{version}/alkimia-%{version}.tar.xz

## upstream patches

## upstreamable patches
# allow use of gmp even if mpir is present
Patch101: alkimia-7.0.1-use_gmp.patch

BuildRequires: cmake
BuildRequires: gcc-c++
BuildRequires: pkg-config
# KF5
BuildRequires: extra-cmake-modules
# Qt5
BuildRequires: cmake(Qt5Core)
BuildRequires: cmake(Qt5DBus)
BuildRequires: cmake(Qt5Test)
# Qt4
BuildRequires: pkgconfig(QtCore)
BuildRequires: pkgconfig(QtDBus)
BuildRequires: pkgconfig(QtTest)

# keep qt4 build unconditionally using gmp
BuildRequires: gmp-devel

# qt5 build conditional
%ifarch ppc64le
# mpir not built on ppc64le... yet, only gmp available
%global gmp gmp
%else
BuildRequires: mpir-devel
%global gmp mpir
%endif

%if 0%{?docs}
BuildRequires: doxygen
%endif

%description
%{summary}

%package devel
Summary: Development files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: gmp-devel
%description devel
%{summary}.

%package        qt5
Summary:        Accounts framework Qt5 bindings
%description    qt5
%{summary}.

%package        qt5-devel
Summary:        Development files for %{name}-qt5
Requires:       %{name}-qt5%{?_isa} = %{version}-%{release}
Requires:       %{gmp}-devel
%description    qt5-devel
%{summary}.

%package        doc
Summary:        API Documentation for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
%description    doc
%{summary}.


%prep
%autosetup -n alkimia-%{version} -p1


%build
## Qt5
mkdir %{_target_platform}-qt5
pushd %{_target_platform}-qt5
%{cmake} .. \
  -DBUILD_TESTING:BOOL=%{?tests:ON}%{!?tests:OFF}
popd

%make_build -C %{_target_platform}-qt5

## docs
%if 0%{?docs}
# auto-update doxygen configuration
doxygen -u %{_target_platform}-qt5/src/libalkimia.doxygen
make libalkimia_apidoc -C %{_target_platform}-qt5
%endif

## Qt4
mkdir %{_target_platform}-qt4
pushd %{_target_platform}-qt4
%{cmake} .. \
  -DBUILD_QT4:BOOL=1 \
  -DBUILD_TESTING:BOOL=%{?tests:ON}%{!?tests:OFF} \
  -DUSE_GMP:BOOL=1
popd

%make_build -C %{_target_platform}-qt4



%install
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}-qt4
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}-qt5

%if 0%{?docs}
mkdir -p %{buildroot}%{_pkgdocdir}
cp -a %{_target_platform}-qt5/src/apidocs/html/ %{buildroot}%{_pkgdocdir}/
%endif


%check
export PKG_CONFIG_PATH=%{buildroot}%{_libdir}/pkgconfig
test "$(pkg-config --modversion libalkimia5)" = "%{version}"
test "$(pkg-config --modversion libalkimia)" = "%{version}"
%if 0%{?tests}
time \
make test ARGS="--output-on-failure --timeout 20" -C %{_target_platform}-qt4 ||:
time \
make test ARGS="--output-on-failure --timeout 20" -C %{_target_platform}-qt5 ||:
%endif


%ldconfig_scriptlets

%files
%doc README.md
%license COPYING*
%{_libdir}/libalkimia.so.7*

%files devel
%{_libdir}/libalkimia.so
%{_includedir}/alkimia/Qt4/
%{_libdir}/cmake/LibAlkimia-7.0/
%{_libdir}//pkgconfig/libalkimia.pc

%ldconfig_scriptlets qt5

%files qt5
%doc README.md
%license COPYING*
%{_libdir}/libalkimia5.so.7*

%files qt5-devel
%dir %{_includedir}/alkimia/
%{_includedir}/alkimia/Qt5/
%{_libdir}/libalkimia5.so
%{_libdir}/pkgconfig/libalkimia5.pc
%{_libdir}/cmake/LibAlkimia5-7.0/

%files doc
%dir %{_pkgdocdir}/
%doc %{_pkgdocdir}/html


%changelog
* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jan 12 2019 Rex Dieter <rdieter@fedoraproject.org> - 7.0.2-1
- 7.0.2

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Mar 31 2018 Rex Dieter <rdieter@fedoraproject.org> - 7.0.1-4
- pull in upstream(ed) patches

* Thu Mar 29 2018 Rex Dieter <rdieter@fedoraproject.org> - 7.0.1-3
- -qt4: make kde4 kmymoney buildable again
- -qt4: use gmp unconditionally (as previous alkimia v5 used gmp)

* Mon Mar 19 2018 Rex Dieter <rdieter@fedoraproject.org> - 7.0.1-2
- -devel: Requires: (gmp,mpir)-devel

* Sun Mar 18 2018 Rex Dieter <rdieter@fedoraproject.org> -  7.0.1-1
- 7.0.1
- -qt5 support

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Feb 01 2016 Rex Dieter <rdieter@fedoraproject.org> 5.0.0-1
- libalkimia-5.0.0

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 4.3.2-7
- Rebuilt for GCC 5 C++11 ABI change

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Feb 04 2012 Rex Dieter <rdieter@fedoraproject.org> 4.3.2-1
- 4.3.2

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Nov 02 2011 Rex Dieter <rdieter@fedoraproject.org> 4.3.1-4
- rebuild (gmp)

* Mon Aug 22 2011 Rex Dieter <rdieter@fedoraproject.org> 4.3.1-3
- .spec cosmetics

* Sat Aug 20 2011 Rex Dieter <rdieter@fedoraproject.org> 4.3.1-2
- BR: gmp-devel
- %%check : don't ignore errors

* Sat Aug 06 2011 Rex Dieter <rdieter@fedoraproject.org> 4.3.1-1
- 4.3.1

* Tue Jun 21 2011 Rex Dieter <rdieter@fedoraproject.org> 4.3.0-1
- first try


